@@ -276,7 +276,6 @@ type Nums = [usize; NUMS_LEN];
 ///
 /// h.insert("test", 101);
 /// ```
-#[cfg_attr(feature = "gc", derive(gc::Trace))]
 #[derive(Clone)]
 pub struct Ham<K, V> {
     array: Vec<Option<V>>,
@@ -289,10 +288,25 @@ pub struct Ham<K, V> {
     last_free: usize,
 
     // To build the hasher that is used to hash keys.
-    #[cfg_attr(feature = "gc", unsafe_ignore_trace)]
     hash_builder: LuaBuildHasher,
 }
 
+#[cfg(feature = "imm_gc")]
+unsafe impl<K: imm_gc::Trace, V: imm_gc::Trace> imm_gc::Trace for Ham<K, V> {
+    imm_gc::unsafe_field_trace! {
+        array: Vec<Option<V>>,
+        hash: Vec<Node<K, V>>,
+    }
+}
+
+#[cfg(feature = "bacon_rajan_cc")]
+impl<K: bacon_rajan_cc::Trace, V: bacon_rajan_cc::Trace> bacon_rajan_cc::Trace for Ham<K, V> {
+    fn trace(&self, t: &mut bacon_rajan_cc::Tracer) {
+        self.array.trace(t);
+        self.hash.trace(t);
+    }
+}
+
 impl<K: FromIndex + fmt::Debug, V: fmt::Debug> fmt::Debug for Ham<K, V> {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         f.debug_map().entries(self.iter()).finish()
