@@ -4,8 +4,8 @@ use core::{
     slice,
 };
 
-use super::{Ham, Node, Nzu};
-use crate::{FromIndex, Key}; // NonZeroUsize
+use super::{Ham, Node};
+use crate::{FromIndex, Idx, Key};
 
 impl<'a, K: FromIndex, V> IntoIterator for &'a Ham<K, V> {
     type Item = (Key<'a, K>, &'a V);
@@ -31,7 +31,7 @@ impl<'a, K: FromIndex + 'a, V: 'a> Iterator for Iter<'a, K, V> {
         for (i, v) in &mut self.array {
             if let Some(ref val) = *v {
                 self.len -= 1;
-                return Some((unsafe { Key::from_index(Nzu::new_unchecked(i + 1)) }, val));
+                return Some((Key::from_index(unsafe { Idx::new_unchecked(i + 1) }), val));
             }
         }
 
@@ -84,7 +84,7 @@ impl<'a, K: FromIndex, V> Iterator for IterMut<'a, K, V> {
         for (i, v) in &mut self.array {
             if let Some(ref mut val) = *v {
                 self.len -= 1;
-                return Some((unsafe { Key::from_index(Nzu::new_unchecked(i + 1)) }, val));
+                return Some((Key::from_index(unsafe { Idx::new_unchecked(i + 1) }), val));
             }
         }
 
@@ -142,7 +142,7 @@ impl<K: FromIndex, V> Iterator for IntoIter<K, V> {
         for (i, v) in &mut self.array {
             if let Some(val) = v {
                 self.len -= 1;
-                return Some((unsafe { K::from_index(Nzu::new_unchecked(i + 1)) }, val));
+                return Some((K::from_index(unsafe { Idx::new_unchecked(i + 1) }), val));
             }
         }
 
