@@ -1,6 +1,5 @@
 use core::{borrow::Borrow, cell::Cell, mem};
 
-#[cfg_attr(feature = "gc", derive(gc::Trace))]
 #[derive(Clone, Debug)]
 pub(super) struct Node<K, V> {
     pub(super) inner: Option<(K, V)>,
@@ -9,6 +8,24 @@ pub(super) struct Node<K, V> {
     pub(super) next: isize,
 }
 
+#[cfg(feature = "imm_gc")]
+unsafe impl<K: imm_gc::Trace, V: imm_gc::Trace> imm_gc::Trace for Node<K, V> {
+    imm_gc::unsafe_field_trace! {
+        inner: Option<(K, V)>,
+    }
+}
+
+#[cfg(feature = "bacon_rajan_cc")]
+impl<K: bacon_rajan_cc::Trace, V: bacon_rajan_cc::Trace> bacon_rajan_cc::Trace for Node<K, V> {
+    fn trace(&self, t: &mut bacon_rajan_cc::Tracer) {
+        // Until Trace is impl'd for (K, V)
+        if let Some((k, v)) = &self.inner {
+            k.trace(t);
+            v.trace(t);
+        }
+    }
+}
+
 impl<K, V> Default for Node<K, V> {
     fn default() -> Self {
         Self {
