@@ -125,12 +125,26 @@ use crate::{map, FromIndex, Ham, IntoIndex, Key};
 ///
 /// [`RefCell`]: core::cell::RefCell
 /// [`Cell`]: core::cell::Cell
-#[cfg_attr(feature = "gc", derive(gc::Trace))]
 #[derive(Clone)]
 pub struct HashArrSet<T> {
     inner: Ham<T, ()>,
 }
 
+#[cfg(feature = "imm_gc")]
+unsafe impl<T: imm_gc::Trace> imm_gc::Trace for HashArrSet<T> {
+    imm_gc::unsafe_field_trace! {
+        inner: Ham<T, ()>,
+    }
+}
+
+// not until () implements Trace
+// #[cfg(feature = "bacon_rajan_cc")]
+// impl<T: bacon_rajan_cc::Trace> bacon_rajan_cc::Trace for HashArrSet<T> {
+//     fn trace(&self, t: &mut bacon_rajan_cc::Tracer) {
+//         self.inner.trace(t);
+//     }
+// }
+
 impl<T> PartialEq for HashArrSet<T>
 where
     T: FromIndex + Hash + Eq,
